InitializeRequest class

Constructors

InitializeRequest({String? libraryId, String? accessKey, String? videoId, String? url, Map<String?, String?>? headers, bool? autoPlay, bool? looping, bool? allowBackgroundPlayback, bool? enableCaching})

Properties

accessKey String?
getter/setter pair
allowBackgroundPlayback bool?
getter/setter pair
autoPlay bool?
getter/setter pair
enableCaching bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers Map<String?, String?>?
getter/setter pair
libraryId String?
getter/setter pair
looping bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
getter/setter pair
videoId String?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) InitializeRequest