VideoState class

Constructors

VideoState({Duration? currentPosition, Duration? totalDuration, int? positionMillis, int? durationMillis, bool? isPlaying, bool? isBuffering, bool? isCompleted, double? bufferedPercentage, VideoQuality? currentQuality, bool? isInPictureInPicture})

Properties

bufferedPercentage double?
getter/setter pair
currentPosition Duration?
getter/setter pair
currentQuality VideoQuality?
getter/setter pair
durationMillis int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isBuffering bool?
getter/setter pair
isCompleted bool?
getter/setter pair
isInPictureInPicture bool?
getter/setter pair
isPlaying bool?
getter/setter pair
positionMillis int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDuration Duration?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) VideoState