VideoState class
Constructors
- VideoState({required Duration currentPosition, required Duration totalDuration, required bool isPlaying, required bool isBuffering, required bool isCompleted, required double bufferedPercentage, required VideoQuality currentQuality, required bool isInPictureInPicture})
Properties
- bufferedPercentage → double
-
final
- currentPosition → Duration
-
final
- currentQuality → VideoQuality
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBuffering → bool
-
final
- isCompleted → bool
-
final
- isInPictureInPicture → bool
-
final
- isPlaying → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDuration → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited