BunnyVideoPlayerEventApi class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBufferEnd(
) → void -
onBufferStart(
) → void -
onComplete(
) → void -
onDownloadProgress(
DownloadProgress progress) → void -
onError(
ErrorInfo error) → void -
onPause(
) → void -
onPipEntered(
) → void -
onPipExited(
) → void -
onPlay(
) → void -
onQualityChanged(
VideoQuality quality) → void -
onStateChanged(
VideoState state) → void -
onTokenExpired(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setup(
BunnyVideoPlayerEventApi? api, {BinaryMessenger? binaryMessenger}) → void
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>